@@ -10,7 +10,7 @@ use Graph::Easy;
 use Scalar::Util qw/weaken/;
 
 @ISA = qw/Graph::Easy::Node Graph::Easy/;
-$VERSION = '0.74';
+$VERSION = '0.76';
 
 use strict;
 use warnings;
@@ -23,7 +23,7 @@ sub _init
   {
   # generic init, override in subclasses
   my ($self,$args) = @_;
-  
+
   $self->{name} = 'Group #'. $self->{id};
   $self->{class} = 'group';
   $self->{_cells} = {};				# the Group::Cell objects
@@ -39,7 +39,7 @@ sub _init
       }
     $self->{$k} = $args->{$k};
     }
-  
+
   $self->{nodes} = {};
   $self->{groups} = {};
   $self->{att} = {};
@@ -70,7 +70,7 @@ sub edges_within
   # edges between nodes inside this group
   my $self = shift;
 
-  wantarray ? ( ord_values ( $self->{edges_within} ) ) : 
+  wantarray ? ( ord_values ( $self->{edges_within} ) ) :
 		scalar keys %{$self->{edges_within}};
   }
 
@@ -146,7 +146,7 @@ sub add_node
   $n->{att}->{group} = $self->{name};
 
   # Register the nodes and the edge with our graph object
-  # and weaken the references. Be carefull to not needlessly
+  # and weaken the references. Be careful to not needlessly
   # override and weaken again an already existing reference, this
   # is an O(N) operation in most Perl versions, and thus very slow.
 
@@ -162,7 +162,7 @@ sub add_member
   {
   # add a node or group to this group
   my ($self,$n) = @_;
- 
+
   if (!ref($n) || !$n->isa("Graph::Easy::Node"))
     {
     if (!ref($self->{graph}))
@@ -187,7 +187,7 @@ sub add_member
   $n->{att}->{group} = $self->{name};
 
   # Register the nodes and the edge with our graph object
-  # and weaken the references. Be carefull to not needlessly
+  # and weaken the references. Be careful to not needlessly
   # override and weaken again an already existing reference, this
   # is an O(N) operation in most Perl versions, and thus very slow.
 
@@ -276,7 +276,7 @@ sub add_nodes
     $n->{group} = $self;
 
     # Register the nodes and the edge with our graph object
-    # and weaken the references. Be carefull to not needlessly
+    # and weaken the references. Be careful to not needlessly
     # override and weaken again an already existing reference, this
     # is an O(N) operation in most Perl versions, and thus very slow.
 
@@ -383,7 +383,7 @@ sub add_group
   $group->{graph} = $self->{graph};
   $group->{group} = $self;
   {
-    no warnings; # dont warn on already weak references
+    no warnings; # don't warn on already weak references
     weaken($group->{graph});
     weaken($group->{group});
   }
@@ -471,7 +471,7 @@ sub _find_label_cell
 	# find top-most, right-most cell
 	next if $lc->{x} > $c->{x} || $lc->{y} < $c->{y};
 	}
-      }  
+      }
     $lc = $c;
     }
 
@@ -483,7 +483,7 @@ sub _find_label_cell
     for my $c (ord_values ( $self->{_cells} ))
       {
       next if $c->{y} != $lc->{y};
-      $left = $c->{x} if !defined $left || $left > $c->{x};  
+      $left = $c->{x} if !defined $left || $left > $c->{x};
       $right = $c->{x} if !defined $right || $right < $c->{x};
       }
     my $center = int(($right - $left) / 2 + $left);
@@ -532,7 +532,7 @@ sub _set_cell_types
     {
     $cell->_set_type($cells);
     }
- 
+
   $self;
   }
 
@@ -581,7 +581,7 @@ L<Graph::Easy::Node> for a list.
 
 	$last_error = $group->error();
 
-	$group->error($error);			# set new messags
+	$group->error($error);			# set new messages
 	$group->error('');			# clear error
 
 Returns the last error message, or '' for no error.
@@ -714,7 +714,7 @@ L<edges()>.
 
 Returns the contained groups of this group as L<Graph::Easy::Group> objects,
 in arbitrary order.
-  
+
 =head2 groups_within()
 
 	# equivalent to $group->groups():
