@@ -6,7 +6,7 @@
 
 package Graph::Easy::Node;
 
-$VERSION = '0.74';
+$VERSION = '0.76';
 
 use Graph::Easy::Base;
 use Graph::Easy::Attributes;
@@ -25,9 +25,9 @@ sub _init
   {
   # Generic init routine, to be overridden in subclasses.
   my ($self,$args) = @_;
-  
+
   $self->{name} = 'Node #' . $self->{id};
-  
+
   $self->{att} = { };
   $self->{class} = 'node';		# default class
 
@@ -42,21 +42,21 @@ sub _init
     $self->{att}->{$k} = $args->{$k} if $k eq 'label';
     }
 
-  # These are undef (to save memory) until needed: 
+  # These are undef (to save memory) until needed:
   #  $self->{children} = {};
   #  $self->{dx} = 0;		# relative to no other node
   #  $self->{dy} = 0;
   #  $self->{origin} = undef;	# parent node (for relative placement)
   #  $self->{group} = undef;
   #  $self->{parent} = $graph or $group;
-  # Mark as not yet laid out: 
+  # Mark as not yet laid out:
   #  $self->{x} = 0;
   #  $self->{y} = 0;
-  
+
   $self;
   }
 
-my $merged_borders = 
+my $merged_borders =
   {
     'dotteddashed' => 'dot-dash',
     'dasheddotted' => 'dot-dash',
@@ -93,7 +93,7 @@ sub _merge_borders
 
   $one = 'none' unless $one;
   $two = 'none' unless $two;
-  
+
   # "nonenone" => "none" or "dotteddotted" => "dotted"
   return $one if $one eq $two;
 
@@ -145,9 +145,9 @@ sub _border_styles
   # already computed values?
   return if defined $cache->{left_border};
 
-  $cache->{left_border} = $border; 
+  $cache->{left_border} = $border;
   $cache->{top_border} = $border;
-  $cache->{right_border} = $border; 
+  $cache->{right_border} = $border;
   $cache->{bottom_border} = $border;
 
   return unless $collapse;
@@ -169,7 +169,7 @@ sub _border_styles
   # Draw border on A (left), and C (left):
   #
   #    +---+
-  #  B | A | C 
+  #  B | A | C
   #    +---+
 
   # Ditto, plus C's border:
@@ -199,14 +199,14 @@ sub _border_styles
   my @where = ('left', 'top', 'right', 'bottom');
   # need to swap arguments to _collapse_borders()?
   my @swapem = (0, 0, 1, 1);
- 
+
   for my $other ($left, $top, $right, $bottom)
     {
     my $side = shift @where;
     my $swap = shift @swapem;
-  
+
     # see if we have a (visible) neighbour on the left side
-    if (ref($other) && 
+    if (ref($other) &&
       !$other->isa('Graph::Easy::Edge') &&
       !$other->isa_cell() &&
       !$other->isa('Graph::Easy::Node::Empty'))
@@ -254,7 +254,7 @@ sub _correct_size
     my $shape = $self->attribute('pointshape');
     if ($style eq 'invisible' || $shape eq 'invisible')
       {
-      $self->{w} = 0; $self->{h} = 0; return; 
+      $self->{w} = 0; $self->{h} = 0; return;
       }
     }
   elsif ($shape eq 'invisible')
@@ -379,7 +379,7 @@ sub _place
   # store our position if we are the first node in that rank
   my $r = abs($self->{rank} || 0);
   my $what = $parent->{_rank_coord} || 'x';	# 'x' or 'y'
-  $parent->{_rank_pos}->{ $r } = $self->{$what} 
+  $parent->{_rank_pos}->{ $r } = $self->{$what}
     unless defined $parent->{_rank_pos}->{ $r };
 
   # a multi-celled node will be stored like this:
@@ -402,7 +402,7 @@ sub _place
         # We might even get away with creating only one filler cell
         # although then its "x" and "y" values would be "wrong".
 
-        my $filler = 
+        my $filler =
 	  Graph::Easy::Node::Cell->new ( node => $self, x => $sx, y => $sy );
         $cells->{"$sx,$sy"} = $filler;
         }
@@ -412,7 +412,7 @@ sub _place
   $self->_update_boundaries($parent);
 
   1;					# did place us
-  } 
+  }
 
 sub _check_place
   {
@@ -447,7 +447,7 @@ sub _do_place
   # Tries to place the node at position ($x,$y) by checking that
   # $cells->{"$x,$y"} is still free. If the node belongs to a cluster,
   # checks all nodes of the cluster (and when all of them can be
-  # placed simultanously, does so).
+  # placed simultaneously, does so).
   # Returns true if the operation succeeded, otherwise false.
   my ($self,$x,$y,$parent) = @_;
 
@@ -564,10 +564,10 @@ sub _wrapped_label
 
   # generate the align array
   my @aligns;
-  my $al = substr($align,0,1); 
+  my $al = substr($align,0,1);
   for my $i (0.. scalar @lines)
     {
-    push @aligns, $al; 
+    push @aligns, $al;
     }
   # cache the result to avoid costly recomputation
   $self->{cache}->{label} = [ \@lines, \@aligns ];
@@ -603,7 +603,7 @@ sub _aligned_label
     $part =~ s/\s+\z//;			# remove spaces at end
     $a =~ s/\\//;			# \n => n
     $a = $al if $a eq 'n';
-    
+
     push @lines, $part;
     push @aligns, $last_align;
 
@@ -629,10 +629,10 @@ my $remap = {
     columns => undef,
     fill => 'background',
     origin => undef,
-    offset => undef, 
+    offset => undef,
     pointstyle => undef,
     pointshape => undef,
-    rows => undef, 
+    rows => undef,
     size => undef,
     shape => undef,
     },
@@ -741,7 +741,7 @@ sub _label_as_html
         while ($line =~ /[BOSUCI]<[^<>]+>/)
       }
     else
-      { 
+      {
       $line =~ s/&/&amp;/g;			# quote &
       $line =~ s/>/&gt;/g;			# quote >
       $line =~ s/</&lt;/g;			# quote <
@@ -755,7 +755,7 @@ sub _label_as_html
 
     $i++;					# next line
     }
-  $name =~ s/^<br>//;				# remove first <br> 
+  $name =~ s/^<br>//;				# remove first <br>
 
   ($name, $switch_to_center);
   }
@@ -821,7 +821,7 @@ sub as_html
   my $c = $class; $c =~ s/\./_/g;	# node.city => node_city
 
   my $html = " <$taga colspan=$cs rowspan=$rs##class####style##";
-   
+
   my $title = $self->title();
   $title =~ s/'/&#27;/g;			# replace quotation marks
 
@@ -842,13 +842,13 @@ sub as_html
     $name = $self->label();
     $name =~ s/\s/\+/g;				# space
     $name =~ s/'/%27/g;				# replace quotation marks
-    $name =~ s/[\x0d\x0a]//g;			# remove 0x0d0x0a and similiar
-    my $t = $title; $t = $name if $t eq ''; 
+    $name =~ s/[\x0d\x0a]//g;			# remove 0x0d0x0a and similar
+    my $t = $title; $t = $name if $t eq '';
     $name = "<img src='$name' alt='$t' title='$t' border='0' />";
     }
   else
     {
-    ($name,$switch_to_center) = $self->_label_as_html(); 
+    ($name,$switch_to_center) = $self->_label_as_html();
     }
 
   # if the label is "", the link wouldn't be clickable
@@ -890,7 +890,7 @@ sub as_html
     # set the fill on the inner part, but the background and no border on the <td>:
     my $inner_style = '';
     my $fill = $self->color_attribute('fill');
-    $inner_style = 'background:' . $fill if $fill; 
+    $inner_style = 'background:' . $fill if $fill;
     $inner_style .= ';border:' . $out->{border} if $out->{border};
     $inner_style =~ s/;\s?\z$//;				# remove '; ' at end
 
@@ -955,7 +955,7 @@ sub as_html
   # "shape: none;" or point means no border, and background instead fill color
   if ($shape =~ /^(point|none)\z/)
     {
-    $out->{background} = $self->color_attribute('background'); 
+    $out->{background} = $self->color_attribute('background');
     $out->{border} = 'none';
     }
 
@@ -1069,7 +1069,7 @@ sub _parent_flow_absolute
 
   return unless defined $flow;
 
-  # in case of relative flow at parent, convert to absolute (right: east, left: west etc) 
+  # in case of relative flow at parent, convert to absolute (right: east, left: west etc)
   # so that "graph { flow: left; }" results in a westward flow
   my $f = $p_flow->{$flow}; $f = $flow unless defined $f;
   $f;
@@ -1101,7 +1101,7 @@ sub flow
   return $cache->{flow} = $flow if defined $flow && $flow =~ /^(0|90|180|270)\z/;
   return $cache->{flow} = Graph::Easy->_direction_as_number($flow)
     if defined $flow && $flow =~ /^(south|north|east|west|up|down)\z/;
-  
+
   # for relative flows, compute the incoming flow as base flow
 
   # check all edges
@@ -1228,7 +1228,7 @@ sub _grow
 	    {
 	    # mark the bit in the vector
 	    # limit to four digits
-	    $nr = 9999 if abs($nr) > 9999; 
+	    $nr = 9999 if abs($nr) > 9999;
 
 	    # if slot was not used yet, count it
 	    $portnr->{$side} ++ if vec($vec->{$side}, $nr, 1) == 0x0;
@@ -1267,7 +1267,7 @@ sub _grow
     $self->_calc_size();
     return $self;
     }
- 
+
   my $need = {};
   my $free = {};
   for my $side (qw/north south east west/)
@@ -1283,13 +1283,13 @@ sub _grow
     }
   # now $need contains for each side the absolute min. number of ports we need
 
-#  use Data::Dumper; 
+#  use Data::Dumper;
 #  print STDERR "# port contraints for $self->{name}:\n";
 #  print STDERR "# count: ", Dumper($cnt), "# max: ", Dumper($max),"\n";
 #  print STDERR "# ports: ", Dumper($portnr),"\n";
 #  print STDERR "# need : ", Dumper($need),"\n";
 #  print STDERR "# free : ", Dumper($free),"\n";
- 
+
   # calculate min. size in X and Y direction
   my $min_x = $need->{north}; $min_x = $need->{south} if $need->{south} > $min_x;
   my $min_y = $need->{west}; $min_y = $need->{east} if $need->{east} > $min_y;
@@ -1330,7 +1330,7 @@ sub _grow
       # if this is a sink node, grow it more by ignoring free ports on the front side
       next if $outgoing == 0 && $front_side eq $side;
       $free_ports += 1 + int(($self->{cx} - $cnt->{$side} - $portnr->{$side}) / 2);
-      }     
+      }
     for my $side (qw/east west/)
       {
       # if this is a sink node, grow it more by ignoring free ports on the front side
@@ -1371,7 +1371,7 @@ sub _un_escape
   # replace \N, \G, \T, \H and \E (depending on type)
   # if $label is false, also replace \L with the label
   my ($self, $txt, $do_label) = @_;
- 
+
   # for edges:
   if (exists $self->{edge})
     {
@@ -1436,7 +1436,7 @@ sub title
       if ($autotitle eq 'label')
         {
         $title = $self->{name};				# fallback to name
-        # defined to avoid overriding "name" with the non-existant label attribute
+        # defined to avoid overriding "name" with the non-existent label attribute
 	# do not use label() here, but the "raw" label of the edge:
         my $label = $self->label(); $title = $label if defined $label;
         }
@@ -1467,7 +1467,7 @@ sub label
   my $label = $self->{att}->{label};
   $label = $self->attribute('label') unless defined $label;
 
-  # for autosplit nodes, use their auto-label first (unless already got 
+  # for autosplit nodes, use their auto-label first (unless already got
   # a label from the class):
   $label = $self->{autosplit_label} unless defined $label;
   $label = $self->{name} unless defined $label;
@@ -1480,7 +1480,7 @@ sub label
     if ($len ne '')
       {
       # allow the old format (pre v0.49), too: "name,12" => 12
-      $len =~ s/^name\s*,\s*//;			
+      $len =~ s/^name\s*,\s*//;
       # restrict to sane values
       $len = abs($len || 0); $len = 99999 if $len > 99999;
       if (length($label) > $len)
@@ -1655,11 +1655,11 @@ sub edges_at_port
     # skip edges starting here if we look at end
     next if $e->{from} eq $self && $attr eq 'end';
 
-    my ($s_p,@ss_p) = $e->port($attr);	
+    my ($s_p,@ss_p) = $e->port($attr);
     next unless defined $s_p;
 
     # same side and same port number?
-    push @edges, $e 
+    push @edges, $e
       if $s_p eq $side && @ss_p == 1 && $ss_p[0] eq $port;
     }
 
@@ -1786,7 +1786,7 @@ sub connections
   return 0 unless defined $self->{graph};
 
   # We need to count the connections, because "[A]->[A]" creates
-  # two connections on "A", but only one edge! 
+  # two connections on "A", but only one edge!
   my $con = 0;
   for my $edge (ord_values ( $self->{edges} ))
     {
@@ -1878,7 +1878,7 @@ sub has_as_predecessor
 
   for my $edge (ord_values ( $self->{edges} ))
     {
-    return 1 if 
+    return 1 if
 	$edge->{to} == $self && $edge->{from} == $other;	# found one
     }
   0;						# found none
@@ -1962,7 +1962,7 @@ sub find_grandparent
     {
     $cur = $cur->{origin};
     }
-  
+
   $cur;
   }
 
@@ -2013,7 +2013,7 @@ sub set_attribute
   my $val = Graph::Easy->unquote_attribute($class,$name,$v);
 
   my $g = $self->{graph};
-  
+
   $g->{score} = undef if $g;	# invalidate layout to force a new layout
 
   my $strict = 0; $strict = $g->{strict} if $g;
@@ -2071,7 +2071,7 @@ sub set_attribute
       # if it doesn't exist, add it
       my $org = $self->{graph}->add_node($val);
       $self->relative_to($org);
-  
+
       # set the attributes, too, so get_attribute('origin') works, too:
       $self->{att}->{origin} = $org->{name};
       }
@@ -2150,7 +2150,7 @@ sub group
 sub add_to_group
   {
   my ($self,$group) = @_;
- 
+
   my $graph = $self->{graph};				# shortcut
 
   # delete from old group if nec.
@@ -2195,7 +2195,7 @@ sub _update_boundaries
   $parent->{cache} = {} unless ref($parent->{cache});
 
   my $cache = $parent->{cache};
-  
+
   $cache->{min_x} = $x if !defined $cache->{min_x} || $x < $cache->{min_x};
   $cache->{min_y} = $y if !defined $cache->{min_y} || $y < $cache->{min_y};
 
@@ -2208,7 +2208,7 @@ sub _update_boundaries
     {
     my $n = $self->{name}; $n = $self unless defined $n;
     print STDERR "Update boundaries for $n (parent $parent) at $x, $y\n";
-  
+
     print STDERR "Boundaries are now: " .
 		 "$cache->{min_x},$cache->{min_y} => $cache->{max_x},$cache->{max_y}\n";
     }
@@ -2484,7 +2484,7 @@ Return a hash with the given text-style properties, aka 'underline', 'bold' etc.
 
 =head2 find_grandparent()
 
-	my $grandpa = $node->find_grandparent(); 
+	my $grandpa = $node->find_grandparent();
 
 For a node that has no origin (is not relative to another), returns
 C<$node>. For all others, follows the chain of origin back until
@@ -2698,7 +2698,7 @@ Returns all nodes (as objects) that we are linking to.
 	my @suc = $node->sorted_successors();
 
 Return successors of the node sorted by their chain value
-(e.g. successors with more successors first). 
+(e.g. successors with more successors first).
 
 =head2 has_as_successor()
 
@@ -2804,7 +2804,7 @@ Sets itself relativ to C<$parent> with the offset C<$dx,$dy>.
 
 	my $shape = $node->shape();
 
-Returns the shape of the node as string, defaulting to 'rect'. 
+Returns the shape of the node as string, defaulting to 'rect'.
 
 =head2 angle()
 
@@ -2843,7 +2843,7 @@ Example:
 	  {
 	  my $self = shift;
 
-	  ' ' . 'onmouseover="alert(\'' . $self->name() . '\');"'; 
+	  ' ' . 'onmouseover="alert(\'' . $self->name() . '\');"';
 	  }
 
 	1;
